@@ -89,7 +89,9 @@ class Users(object):
 			    photo_url=photo_url,
 			    disabled=False)
 			success = True
-		except: success = False
+		except Exception as e: 
+			success = False
+			error = e
 
 		# handle success.
 		if success:
@@ -98,7 +100,7 @@ class Users(object):
 				"uid":user.uid,
 			})
 		else:
-			return r3sponse.error_response(f"Failed to create user [{email}].")
+			return r3sponse.error_response(f"Failed to create user [{email}], error: {error}.")
 
 		#
 	def update(self,
@@ -143,13 +145,15 @@ class Users(object):
 				photo_url=photo_url,
 				disabled=False)
 			success = True
-		except: success = False
+		except Exception as e: 
+			success = False
+			error = e
 
 		# handle success.
 		if success:
 			return r3sponse.success_response(f"Successfully updated user [{username}].")
 		else:
-			return r3sponse.error_response(f"Failed to update user [{username}].")
+			return r3sponse.error_response(f"Failed to update user [{username}], error: {error}.")
 
 		#
 	def delete(self, 
@@ -159,11 +163,13 @@ class Users(object):
 		try:
 			auth.delete(uid)
 			success = True
-		except: success = False
+		except Exception as e: 
+			success = False
+			error = e
 		if success:
 			return r3sponse.success_response(f"Successfully deleted user [{uid}].")
 		else:
-			return r3sponse.error_response(f"Failed to delete user [{uid}].")
+			return r3sponse.error_response(f"Failed to delete user [{uid}], error: {error}.")
 	def iterate(self):
 		return auth.list_users().iterate_all()
 	def verify_id_token(self, id_token):
@@ -181,11 +187,13 @@ class Users(object):
 			uid = decoded_token['uid']
 			if uid == None: success = False
 			else: success = True
-		except: success = False
+		except Exception as e: 
+			success = False
+			error = e
 		if success:
 			return r3sponse.success_response("You are signed in.", {"uid":uid})
 		else:
-			return r3sponse.error_response("You are not signed in.")
+			return r3sponse.error_response("You are not signed in., error: {error}.")
 
 		#
 
