@@ -22,11 +22,11 @@ class users():
 				"name",
 				"password",
 				"verify_password",])
-			if response["error"] != None: return JsonResponse(response)
+			if response["error"] != None: return response
 
 			# check firebase set.
 			if firebase == None:
-				return r3sponse.error_response("Set the firebase of the requests.users class. [fir3base.requests.users.firebase = your_firebase_object", django=True)
+ 				return r3sponse.error_response("Set the firebase of the requests.users class. [fir3base.requests.users.firebase = your_firebase_object")
 
 			# make request.
 			response = firebase.users.create(
@@ -38,4 +38,4 @@ class users():
 			try:
 				if response["success"]: del response["user"]
 			except KeyError: a=1
-			return JsonResponse(response)
+			return response
